Commons
=======

Enums
-----

.. currentmodule:: biomol.enums

.. autosummary::
    :toctree: ./generated
    :nosignatures:

    MoleculeType
    PolymerType
    StructureLevel


Exceptions
----------

.. currentmodule:: biomol.exceptions

.. autosummary::
    :toctree: ./generated
    :nosignatures:

    BioMolError
    FeatureKeyError
    FeatureOperationError
    ViewOperationError
    StructureLevelError
    IndexInvalidError
    IndexMismatchError
    IndexOutOfBoundsError
